SLik object (as produced by MSL) and deduces confidence bounds for each parameter, using a (profile, if relevant) likelihood ratio method.
"confint"(object, parm, level=0.95, verbose=interactive(), fixed=NULL,which=c(TRUE,TRUE),...)SLik or SLikp object
NULL the computed interval is a profile confidence interval over all parameters excluding parm.
fixed allows one to set fixed values to some of these parameters.
SLik object are considered) parameter point for the lower bound, and the full parameter point for the upper bound
## see main documentation page for the package
Run the code above in your browser using DataLab