logLs method uses a standard smoothing method (prediction under linear mixed models, a.k.a. Kriging) to infer a likelihood surface, using as input likelihood values themselves inferred with some error for different parameter values. The tailp method use a similar approach for smoothing binomial response data, using the algorithms implemented in the spaMM package for fitting GLMMs with autocorrelated random effects.
"infer_surface"(object, method="REML",verbose=interactive(),allFix=NULL,...)
"infer_surface"(object, method="PQL",verbose=interactive(),allFix,...)infer_logLs or infer_tailp.
method="GCV", a generalized cross-validation procedure is used (for logLs method only). Other methods are as described in the HLfit documentation.
infer_surface.logLs, this should typically include values of all parameters fitted by spaMM::corrHLfit ($\rho,\nu,\phi,\lambda$, and $etaFix=$\beta$).
SLik or SLikp, which is a list including an HLfit object as returned by corrHLfit, and additional members not documented here.
## see main documentation page for the package
Run the code above in your browser using DataLab