Learn R Programming

Infusion (version 1.0.0)

plot.SLik: Plot SLik or SLikp objects

Description

Mostly conceived for exposition purposes, for the two-parameters case. The black-filled points are those for which the observed summary statistic was outside of the convex hull of the simulated empirical distribution. The crosses mark the estimated ML point and the confidence intervals points, that is, the outmost points on the contour defined by the profile likelihood threshold for the profile confidence intervals. There is a pair of CI points for each interval. The smaller black dots mark points added in the latest iteration, if refine was used.

Usage

"plot"(x, y, filled=FALSE, decorations=NULL, color.palette = NULL, plot.axes = NULL, plot.title = NULL, ...)

Arguments

x
An object of class SLik or SLikp
y
Not used, but included for consistency with the plot generic.
filled
whether to plot a mapMM or a filled.mapMM.
decorations
Graphic directives added to the default decorations value in calls of mapMM or a filled.mapMM (see the source code of plot.SLik for the latter default values).
color.palette
Either NULL or a function that can replace the default color function used by plot.SLik. Thefunction must have a single argument, giving the number of color levels.
plot.title
statements which replace the default titles to the main plot (see Details).
plot.axes
statements which replace the default axes on the main plot (see Details).
...
further arguments passed to or from other methods (currently can be used to pass a few arguments such as map.asp in all cases, or variances to filled.mapMM).

Value

Details

Different graphic functions are called depending on the number of estimated parameters. For two parameters, mapMM or filled.mapMM are called. For more than two parameters, spaMM.filled.contour is called. See the documentation of these functions for the appropriate format of the plot.title and plot.axes arguments.

Examples

Run this code
## Not run: 
# ## Using 'slik' object from the example in help("Infusion-package") 
#   plot(slik, filled=TRUE,
#        plot.title=quote(title("Summary likelihood ratio surface",
#                               xlab=expression(mu),
#                               ylab=expression(sigma^2))))
# ## End(Not run)

Run the code above in your browser using DataLab