The parameter value (as a vector of named values) for which the profile is to be computed
fixed
When this is NULL the computed interval is a profile confidence interval over all parameters excluding value.
fixed allows one to set fixed values to some of these parameters.
return.optim
If this is TRUE, and if maximization of likelihood given value and fixed is indeed required, then the full result of the optim call is returned.
...
For SLik_j method, arguments passed to SLik method.
For SLik_j method, currently not used.
Value
The predicted summary profile log-likelihood; or possibly the result of an optim call if return.optim is TRUE.