This is a generic function with currently methods for SLik and SLikp objects (as produced by MSL). Depending on the value of its newsimuls argument, and on whether the function used to generate empirical distributions can be called by R, it (1) defines new parameters points and/or (2) infers their summary likelihood or tail probabilities for each parameter point independently, adds the inferred values results as input for refined inference of likelihood or P-value response surface, and provides new point estimates and confidence intervals.
"refine"(object,...)
"refine"(object, surfaceData, maxit = 1, n = NULL, useEI = list(max=TRUE,profileCI=TRUE,rawCI=FALSE), newsimuls = NULL, useCI = TRUE, level = 0.95, verbose = list(most=interactive(),movie=FALSE), precision = Infusion.getOption("precision"), method,...)SLik object
object and thus not specified by user, usable as input for infer_surface.
precision argument)
n argument of sample_volume)
rparam
SLik_j method, a matrix or data frame, with the same parameters and summary statistics as the data of the original infer_SLik_joint call.
For other methods, a list of simulation of distributions of summary statistics, in the same format as for link{add_simulation}.
If no such list is provided (i.e., if newsimuls remains NULL), the attr(object$logLs,"Simulate") function is used (it is inherited from the Simulate
argument of add_simulation through the initial sequence of calls of functions add_simulation,
infer_logLs or infer_tailp, and infer_surface). If no such function is available, then this function returns parameters for which new distribution should be provided by the user.
verbose$movie controls whether such plots are produced for all iterations. verbose$most controls other verbosity, including whether a final plot is produced.
maxit is reached, or this precision is reached for these MSEs.
A given precision on the CI bounds themselves might seem more interesting, but is not well specified by a single precision parameter if the parameters are on widely different scales.
method argument of infer_surface). The ith element of the vector is
used in the ith iteration, if available; otherwise the last element is used. This argument is not always heeded, in that REML may be used if the suggested method is GCV but it appears to perform poorly. The default for SLikp objects is PQL; for SLik objects it is "REML".
refine passes these arguments to the plot method suitable for the object.
SLik or SLik_j object.
## see main documentation page for the package
Run the code above in your browser using DataLab